summaryrefslogtreecommitdiffstats
path: root/kioslave/audiocd/plugins/lame/collectingprocess.h
diff options
context:
space:
mode:
Diffstat (limited to 'kioslave/audiocd/plugins/lame/collectingprocess.h')
-rw-r--r--kioslave/audiocd/plugins/lame/collectingprocess.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kioslave/audiocd/plugins/lame/collectingprocess.h b/kioslave/audiocd/plugins/lame/collectingprocess.h
index a98c4b47..df5c180d 100644
--- a/kioslave/audiocd/plugins/lame/collectingprocess.h
+++ b/kioslave/audiocd/plugins/lame/collectingprocess.h
@@ -36,14 +36,14 @@
#include <kprocess.h>
/**
* @short An output collecting KProcess class.
*
* This class simplifies the usage of KProcess by collecting all output
* (stdout/stderr) of the process.
*
* @author Ingo Kloecker <kloecker@kde.org>
*/
-class CollectingProcess : public KProcess {
+class CollectingProcess : public TDEProcess {
Q_OBJECT
public:
@@ -61,8 +61,8 @@ public:
TQByteArray collectedStderr();
private slots:
- void slotReceivedStdout( KProcess *, char *, int );
- void slotReceivedStderr( KProcess *, char *, int );
+ void slotReceivedStdout( TDEProcess *, char *, int );
+ void slotReceivedStderr( TDEProcess *, char *, int );
private:
class Private;
@@ -36,14 +36,14 @@
#include <kprocess.h>
/**
- * @short An output collecting KProcess class.
+ * @short An output collecting TDEProcess class.
*
@@ -36,14 +36,14 @@
*
- * This class simplifies the usage of KProcess by collecting all output
+ * This class simplifies the usage of TDEProcess by collecting all output
* (stdout/stderr) of the process.
*